@@ -6,7 +6,7 @@
 from pathlib import Path
 from tempfile import gettempdir, TemporaryDirectory
 
-from DrissionPage.functions.tools import port_is_using, clean_folder
+from DrissionPage.commons.tools import port_is_using, clean_folder
 from .options_manage import OptionsManager
 
 
@@ -20,9 +20,10 @@ class ChromiumOptions(object):
         self._user = 'Default'
         self._prefs_to_del = []
 
-        if read_file:
-            self.ini_path = str(ini_path) if ini_path else str(Path(__file__).parent / 'configs.ini')
-            om = OptionsManager(self.ini_path)
+        if read_file is not False:
+            ini_path = str(ini_path) if ini_path else None
+            om = OptionsManager(ini_path)
+            self.ini_path = om.ini_path
             options = om.chrome_options
 
             self._download_path = om.paths.get('download_path', None)
@@ -391,7 +392,7 @@ class PortFinder(object):
     used_port = []
 
     def __init__(self):
-        self.tmp_dir = Path(gettempdir()) / 'DrissionPageTempFolder'
+        self.tmp_dir = Path(gettempdir()) / 'DrissionPage' / 'TempFolder'
         self.tmp_dir.mkdir(parents=True, exist_ok=True)
         if not PortFinder.used_port:
             clean_folder(self.tmp_dir)
