@@ -8,15 +8,37 @@ from pathlib import Path
 from re import search
 from typing import Union
 
-from selenium import webdriver
-
+from .commons.constants import Settings
+from .commons.tools import unzip
 from .configs.chromium_options import ChromiumOptions
-from .configs.driver_options import DriverOptions
 from .configs.options_manage import OptionsManager
-from .drission import Drission
-from .functions.tools import unzip
 from .session_page import SessionPage
 
+try:
+    from selenium import webdriver
+    from DrissionPage.mixpage.drission import Drission
+    from .configs.driver_options import DriverOptions
+except ModuleNotFoundError:
+    pass
+
+
+def raise_when_ele_not_found(on_off=True):
+    """设置全局变量，找不到元素时是否抛出异常
+    :param on_off: True 或 False
+    :return: None
+    """
+    Settings.raise_ele_not_found = on_off
+
+
+def configs_to_here(save_name=None):
+    """把默认ini文件复制到当前目录
+    :param save_name: 指定文件名，为None则命名为'dp_configs.ini'
+    :return: None
+    """
+    om = OptionsManager('default')
+    save_name = f'{save_name}.ini' if save_name is not None else 'dp_configs.ini'
+    om.save(save_name)
+
 
 def show_settings(ini_path=None):
     """打印ini文件内容
@@ -287,8 +309,9 @@ def get_chrome_path(ini_path=None,
         try:
             key = winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE,
                                  r'SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\chrome.exe',
-                                 # r'HKEY_CURRENT_USER\Software\Google\Chrome\BLBeacon\version',
                                  reserved=0, access=winreg.KEY_READ)
+            # key = winreg.OpenKey(winreg.HKEY_CURRENT_USER, r'Software\Google\Chrome\BLBeacon\version',
+            #                      reserved=0, access=winreg.KEY_READ)
             k = winreg.EnumValue(key, 0)
             winreg.CloseKey(key)
 
